@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import pytest
 from datetime import datetime, timedelta, timezone
 
 from google import showcase_v1beta1
@@ -27,3 +28,16 @@ def test_lro(echo):
     response = future.result()
     assert isinstance(response, showcase_v1beta1.WaitResponse)
     assert response.content.endswith('the snails...eventually.')
+
+
+@pytest.mark.asyncio
+async def test_lro_async(async_echo):
+    future = await async_echo.wait({
+        'end_time': datetime.now(tz=timezone.utc) + timedelta(seconds=1),
+        'success': {
+            'content': 'The hail in Wales falls mainly on the snails...eventually.'
+        }}
+    )
+    response = await future.result()
+    assert isinstance(response, showcase_v1beta1.WaitResponse)
+    assert response.content.endswith('the snails...eventually.')
